"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.CUSTOM_MESSAGE_RULE_SUFFIX = void 0;
const rules_1 = __importDefault(require("@commitlint/rules"));
exports.CUSTOM_MESSAGE_RULE_SUFFIX = '-message';
/**
 * generate wrapper config function
 * @param customMessageConfig custom message config
 * @returns wrapper function
 */
exports.default = (customMessageConfig) => {
    /**
     * user config custom rule message keys
     *
     * @example
     *
     * ```ts
     * ['subject-empty', ...]
     * ```
     */
    const customMessageKeys = Object.keys(customMessageConfig).map((k) => k.slice(0, -exports.CUSTOM_MESSAGE_RULE_SUFFIX.length));
    /**
     * default rule keys
     */
    const ruleConfigKeys = Object.keys(rules_1.default);
    /**
     * replace rules
     */
    const pluginConfig = {
        rules: {},
    };
    /**
     * user config plugin keys
     *
     * will replace default rules message
     */
    const pluginKeys = ruleConfigKeys.filter((k) => customMessageKeys.includes(k));
    // if not user config custom message key, skip
    if (pluginKeys.length) {
        for (const rule of pluginKeys) {
            // replace default lint function
            const handle = (parsed, when, value) => {
                // call default lint function, get lint result
                const [valid, message] = rules_1.default[rule](parsed, when, value);
                // get replace message
                const replaceMessage = customMessageConfig[`${rule}${exports.CUSTOM_MESSAGE_RULE_SUFFIX}`];
                if (typeof replaceMessage === 'string') {
                    return [valid, replaceMessage];
                }
                return [valid, replaceMessage(valid, rule, message || '')];
            };
            pluginConfig.rules[rule] = handle;
        }
    }
    return pluginConfig;
};
//# sourceMappingURL=index.js.map